#pragma once
/*
* BoardController.h
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QObject>
#include <QtGui/QGraphicsScene>

//====================================================================================
// Project Includes
//====================================================================================
#include "icontextcallback.h"
#include "ilogcallback.h"

//====================================================================================
// Local Includes
//====================================================================================

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
class DGraphicsPathItem;
class Event;
class TempModify;
class QGraphicsScene;
class QGraphicsItem;
class QGraphicsRectItem;
class QGraphicsEllipseItem;
class QGraphicsLineItem;
class DGraphicsRectItem;
class DGraphicsEllipseItem;
class DGraphicsLineItem;
class DGraphicsTextItem;
class QGraphicsView;
class QPointF;
struct iContext;

class BoardController : public QObject, public iLogCallback, public iContextCallback
{

public:
  QGraphicsItem* CreateShape();

  virtual ~BoardController(void);

  static BoardController& GetSingleton(QGraphicsScene* graphicsScene = 0, QGraphicsView* graphicsView = 0)
  {
    if(!myself)
    {
      myself = new BoardController(graphicsScene, graphicsView);
    }
    return *myself;
  }

  iContext* GetContext() const
  {
    return context;
  }

  virtual void PressCallBack(iDGraphicsItem* item);
  virtual void MoveCallBack(iDGraphicsItem* item);
  virtual void ReleaseCallBack(iDGraphicsItem* item);

  void AddEvent(const Event& event);
  void ModifyEvent(const Event& event);
  void DeleteEvent(const Event& event);
  bool DeleteAll();

  inline void AddItem(QGraphicsItem* item)
  {
    boardModel->addItem(item);
  }

  inline void RemoveItem(QGraphicsItem* item)
  {
    boardModel->removeItem(item);
  }

  void MoveObjects(QPointF& change);

  void EraseObjects();

  inline QGraphicsScene* GetBoardModel()
  {
    return boardModel;
  }

  void InstantiateModifiers();

  virtual void ClearSelection();
  inline bool GetSendTempEvents() { return sendTempEvents; }

private:
  BoardController(QGraphicsScene* graphicsScene, QGraphicsView* graphicsView);
  static BoardController* myself;
  QGraphicsScene* boardModel;
  QGraphicsView* boardView;
  iContext* context;
  bool sendTempEvents;
  bool resumingSession;

  Q_OBJECT
    public slots:
      void SquareButtonClicked();
      void LineButtonClicked();
      void TextButtonClicked();
      void EllipseButtonClicked();
      void FreehandButtonClicked();
      void EraseButtonClicked();
      void MoveButtonClicked();
      void SelectButtonClicked();
      void OnExportClicked();
      void OnUndoClicked();
      void OnRedoClicked();
      void SaveSessionClicked();
      void ResumeSessionClicked();
      void FastConnectionClicked();
      void SlowConnectionClicked();	
};
