/*
* Caster.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtGui/QGraphicsItem>

//====================================================================================
// Project Includes
//====================================================================================
#include <iostream>
#include "graphics/DGraphicsLineItem.h"
#include "graphics/DGraphicsTextItem.h"
#include "graphics/DGraphicsEllipseItem.h"
#include "graphics/DGraphicsRectItem.h"
#include "graphics/DGraphicsPathItem.h"

//====================================================================================
// Local Includes
//====================================================================================
#include "Caster.h"

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------


iDGraphicsItem* Caster::Cast(QGraphicsItem* qItem)
{
  /*we will now attempt a series of dynamic casts in order to 
  turn the QGraphics item into a DGraphicsItem, item will be null 
  until the cast is sucessfull.
  */
  iDGraphicsItem* item = dynamic_cast<DGraphicsRectItem*>(qItem);
  if(!item)
  {
    item = dynamic_cast<DGraphicsEllipseItem*>(qItem);
  }

  if(!item)
  {
    item = dynamic_cast<DGraphicsLineItem*>(qItem);
  }

  if(!item)
  {
    item = dynamic_cast<DGraphicsTextItem*>(qItem);
  }

  if(!item)
  {
    item = dynamic_cast<DGraphicsPathItem*>(qItem);
  }

  if(item)
  {
    return item;
  }
  else
  {
    std::cerr << "A casting error has occured";
    return NULL;
  }
}

QGraphicsItem* Caster::Cast(iDGraphicsItem* qItem)
{
  /*we will now attempt a series of dynamic casts in order to 
  turn the DGraphicsItem item into a QGraphicsItem, item will be null 
  until the cast is sucessfull.
  */
  QGraphicsItem* item = dynamic_cast<QGraphicsRectItem*>(qItem);
  if(!item)
  {
    item = dynamic_cast<QGraphicsEllipseItem*>(qItem);
  }

  if(!item)
  {
    item = dynamic_cast<QGraphicsLineItem*>(qItem);
  }

  if(!item)
  {
    item = dynamic_cast<QGraphicsTextItem*>(qItem);
  }

  if(!item)
  {
    item = dynamic_cast<QGraphicsPathItem*>(qItem);
  }

  if(item)
  {
    return item;
  }
  else
  {
    std::cerr << "A reverse casting error has occured";
    return NULL;
  }
}
