/*
* ChatController.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtGui/QScrollBar>
#include <QtGui/QLineEdit>
#include <QtGui/QTextEdit>
#include <QtGui/QPushButton>
#include <QtGui/QTextDocument>

//====================================================================================
// Project Includes
//====================================================================================
#include "log/log.h"
#include "log/chat.h"
#include "network/network.h"
#include "raknet/BitStream.h"
#include <iostream>

//====================================================================================
// Local Includes
//====================================================================================
#include "ChatController.h"

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------


using namespace RakNet;
using namespace std;
ChatController * ChatController::myself = 0;

ChatController::ChatController(){
  // Setup stylesheet
  this->textDoc = new QTextDocument();
  this->styleSheet = new QString("sender: { font-weight: bold; font-style: italic; } timestamp: { opacity: 0.5 } * {font-color: green;}");
  this->textDoc->setDefaultStyleSheet(*this->styleSheet);
  //setup the chat controller with the callback system
  Chat::RegisterCallback( this );
}
void ChatController::setInput(QLineEdit *in){
  //keep track of the input widget.
  this->inputWidget = in;
}

void ChatController::setOuptut(QTextEdit * out){
  //keep track of the output widgets and assign the model to the view.
  this->outputWidget = out;
  this->outputWidget->setDocument(this->textDoc);
}

ChatController::~ChatController(void)
{
}

void ChatController::sendButtonClicked()
{
  // Can be called programatically, we don't want blank lines
  if(!this->inputWidget->text().length())
  {
    return;
  }

  //call the log class to record this event occuring.
  //the chatEvent will then callback the appendMessage() method as part of it's execute() method
  Chat* chatEvent = new Chat(this->inputWidget->text());
  //2) Call add(chat); to add to log
  Log::GetSingleton().Add(chatEvent);
  //3) Send the message over the network.
  chatEvent->SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);
  //clear the contents of the input text box
  this->inputWidget->setText("");
  this->sendButton->setEnabled(false);
}

void ChatController::AddEvent(const Event& event)
{
  /* instantiate the chat event and adjust the time for local systems
  everybody should see their local time, regardless of other people's locations.
  */
  const Chat& chat = (const Chat&) event;

  short timeDifference = chat.GetOwner()->GetTimeDifference();
  QTime timeSent = chat.GetTime();
  timeSent.setHMS(timeSent.hour() - timeDifference/60, timeSent.minute() - timeDifference%60, timeSent.second());

  QString message(
    "[" + timeSent.toString() + "]"
    + "<" + chat.GetSender() + ">"
    + " " + chat.GetText() + " "
    + "\n");
  //setup auto scrolling to ensure the text rolls down.
  this->outputWidget->insertPlainText(message);
  this->outputWidget->verticalScrollBar()->setValue(outputWidget->verticalScrollBar()->maximum());
}

void ChatController::lineEditReturn()
{
  //conventional method of entering text quickly through the enter key being pressed.
  this->sendButtonClicked();
}

void ChatController::toggleButton(const QString &text)
{
  //only enable the send button if there is text to send.
  this->sendButton->setEnabled(text.length() > 0);
}

void ChatController::DeleteAll()
{
  //clear the contents of the the chat system in case of session reset.
  outputWidget->clear();
}
