#pragma once

/*
* ChatController.h
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QObject>
#include <QtCore/QString>

//====================================================================================
// Project Includes
//====================================================================================
#include "ilogcallback.h"

//====================================================================================
// Local Includes
//====================================================================================

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
class QPushButton;
class QLineEdit;
class QTextEdit;
class QTextDocument;

class Log;
class Event;
class TempModify;

class ChatController : public QObject, public iLogCallback
{
  Q_OBJECT
private:
  // I/O
  QLineEdit *inputWidget;
  QTextEdit *outputWidget;
  QPushButton *sendButton;
  QTextDocument *textDoc;
  QString *styleSheet;

  // Const/dest
  ChatController();
  static ChatController* myself;

  public slots:
    void lineEditReturn();
    void sendButtonClicked();
    void toggleButton(const QString &text);

public:
  // Functions
  void AddEvent(const Event& chat);
  void ModifyEvent(const Event& chat) {}
  void ModifyEvent(const TempModify& modify) {}
  void DeleteEvent(const Event& chat) {}
  void DeleteAll();

  // Private access methods
  void setInput(QLineEdit *in);
  void setOuptut(QTextEdit * out);
  void setSendButton(QPushButton *sendButton) { this->sendButton = sendButton; }

  // Const/dest
  static ChatController& GetSingleton()
  {
    if(!myself)
    {
      myself = new ChatController();
    }
    return *myself;
  }
  virtual ~ChatController(void);
};
