/*
* ItemMenu.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QMenu>
#include <QtGui/QGraphicsItem>

//====================================================================================
// Project Includes
//====================================================================================
#include "idgraphicsitem.h"
#include "log/modify.h"
#include "network/network.h"
#include "raknet/BitStream.h"

//====================================================================================
// Local Includes
//====================================================================================
#include "Caster.h"
#include "ItemMenu.h"
#include "gui.h"

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
using namespace RakNet;

ItemMenu::ItemMenu(iDGraphicsItem* item)
{
  //QT Creator auto generated code for instantiating the UI
  this->currentItem = item;
  actionLocked = new QAction(&GUI::GetSingleton().window);
  actionLocked->setObjectName(QString::fromUtf8("actionLocked"));
  actionLocked->setCheckable(true);
  actionResize = new QAction(&GUI::GetSingleton().window);
  actionResize->setObjectName(QString::fromUtf8("actionResize"));
  actionBring_Forward = new QAction(&GUI::GetSingleton().window);
  actionBring_Forward->setObjectName(QString::fromUtf8("actionBring_Forward"));
  actionSend_Backwards = new QAction(&GUI::GetSingleton().window);
  actionSend_Backwards->setObjectName(QString::fromUtf8("actionSend_Backwards"));

  menuMenuBar = new QMenu();
  menuMenuBar->setObjectName(QString::fromUtf8("menuMenuBar"));

  menuMenuBar->addAction(actionLocked);
  menuMenuBar->addAction(actionResize);
  menuMenuBar->addAction(actionBring_Forward);
  menuMenuBar->addAction(actionSend_Backwards);
  QObject::connect(actionLocked,SIGNAL(triggered(bool)),this,SLOT(lockedClicked(bool)));
  QObject::connect(actionResize,SIGNAL(triggered()),this,SLOT(resizeClicked()));
  QObject::connect(actionBring_Forward,SIGNAL(triggered()),this,SLOT(bringForwardsClicked()));
  QObject::connect(actionSend_Backwards,SIGNAL(triggered()),this,SLOT(sendBackwardsClicked()));
  retranslateUi();
  actionLocked->setChecked(currentItem->GetLock());
}

ItemMenu::~ItemMenu(void)
{
}

void ItemMenu::retranslateUi()
{
  //Qt auto generated code for english translation
  actionLocked->setText(QApplication::translate("MainWindowClass", "Locked", 0, QApplication::UnicodeUTF8));
  actionResize->setText(QApplication::translate("MainWindowClass", "Resize", 0, QApplication::UnicodeUTF8));
  actionBring_Forward->setText(QApplication::translate("MainWindowClass", "Bring Forward", 0, QApplication::UnicodeUTF8));
  actionSend_Backwards->setText(QApplication::translate("MainWindowClass", "Send Backwards", 0, QApplication::UnicodeUTF8));
}

void ItemMenu::popUp(QPoint *pos)
{
  this->menuMenuBar->popup(*pos);
}

void ItemMenu::lockedClicked(bool checked)
{
  currentItem->SetLock(checked);
}
void ItemMenu::resizeClicked()
{
  //initiate the resize process to the current item.
  this->currentItem->ResizeStart( BoardController::GetSingleton().GetSendTempEvents() );
}
void ItemMenu::bringForwardsClicked()
{
  /*cast dgraphicsitem to a qgraphics item so we can call zvalue operations
  increase the z value on qgraphicsitem
  create a modify event to alter the z value pass the current descriptor through
  send the event to the network
  add the event to the log */
  
  QGraphicsItem *item = Caster::Cast(currentItem);
  item->setZValue(item->zValue()+1);
  Modify* modify = new Modify(currentItem->GetDesc(), currentItem->GetEvent());
  modify->SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);
  Log::GetSingleton().Add(modify);
}
void ItemMenu::sendBackwardsClicked()
{
  /*cast dgraphicsitem to a qgraphics item so we can call zvalue operations
  decrease the z value on qgraphicsitem
  create a modify event to alter the z value pass the current descriptor through
  send the event to the network
  add the event to the log*/
  QGraphicsItem *item = Caster::Cast(currentItem);
  item->setZValue(item->zValue()-1);
  Modify* modify = new Modify(currentItem->GetDesc(), currentItem->GetEvent());
  modify->SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);
  Log::GetSingleton().Add(modify);
}
