/*
* dialog.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QByteArray>
#include <QtGui/QPushButton>

//====================================================================================
// Project Includes
//====================================================================================
#include <iostream>
#include "network/network.h"
#include "dialog.h"
#include "log/log.h"

//====================================================================================
// Local Includes
//====================================================================================
#include "BoardController.h"
#include "ChatController.h"

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------


JoinSessionDialog::JoinSessionDialog(QWidget *parent, Qt::WFlags flags)
: QDialog(parent, flags)
{
  dialog.Setup(this, true);
}

JoinSessionDialog::~JoinSessionDialog()
{

}

void JoinSessionDialog::accept()
{
  /*if the user clicks ok on start session dialog,
  retrieve the information from the dialog box and assign it to objects/variables as required.
  */
  int port = dialog.GetPort();
  QByteArray ip = dialog.GetIP();
  QByteArray username = dialog.GetUsername();
  QByteArray password = dialog.GetPassword();

  if( port > 0 && ip.size() != 0 && username.size() != 0 )
  {
    // Clear the contents of the board and log. For open > connect > connect.
    if(BoardController::GetSingleton().DeleteAll())
    {
      ChatController::GetSingleton().DeleteAll();
      Log::GetSingleton().ClearLog();
    }
    Network::GetSingleton().Connect(port, port, ip, username, password, true);
    this->setVisible(false);
  }
}

void JoinSessionDialog::reject()
{
  //On cancelation hide the join dialog
  this->setVisible(false);
}

StartSessionDialog::StartSessionDialog(QWidget *parent, Qt::WFlags flags)
: QDialog(parent, flags)
{
  dialog.Setup(this);
}

StartSessionDialog::~StartSessionDialog()
{
}

void StartSessionDialog::accept()
{
  /*if the user clicks ok on start session dialog,
  retrieve the information from the dialog box and assign it to objects/variables as required.
  */
  int port = dialog.GetPort();
  QByteArray username = dialog.GetUsername();
  QByteArray password = dialog.GetPassword();
  //start the network connection passing the retrieved information.
  Network::GetSingleton().Connect(port, port, "", username, password);

  // Clear the contents of the board and log. For open > connect > connect.
  if(BoardController::GetSingleton().DeleteAll())
  {
    ChatController::GetSingleton().DeleteAll();
    Log::GetSingleton().ClearLog();
  }

  this->setVisible(false);
}

void StartSessionDialog::reject()
{
  //hide the startsession dialog box if the user clicks cancel.
  this->setVisible(false);
}

void StartSessionDialog::textChang(const QString &text)
{
  /*if any of the text dialogs change, we disable the OK button if 
  all mandatory fields are not filled in.
  */
  if ( 
      (dialog.portBox->text().length() != 0) &&
      (dialog.usernameBox->text().length() != 0)
      ) 
  { 
    dialog.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(true); 
  }
  else {
    dialog.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false); 
  }
}

void JoinSessionDialog::textChang(const QString &text)
{
  std::cout << "d";
  if ( 
    (dialog.ipBox->text().length() != 0) &&
    (dialog.portBox->text().length() != 0) &&
    (dialog.usernameBox->text().length() != 0)
    ) { 
      dialog.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(true); 
  }
  else {
    dialog.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false); 
  }
}
