/*
* gui.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/

//====================================================================================
// QT Includes
//====================================================================================

//====================================================================================
// Project Includes
//====================================================================================

//====================================================================================
// Local Includes
//====================================================================================
#include "gui.h"
#include "mainwindow.h"
#include "tabula.h"

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//-----------------------------------------------------------------------------------
GUI* GUI::myself = NULL;

void GUI::Open()
{
  //instantiate and initialise the GUI. Singleton ensures we do it once
  GetSingleton().Init();
}

void GUI::Close()
{
  //destroy the GUI
  delete myself;
}

void GUI::Init()
{
  // Init the board.
  window.ui.graphicsView->setInteractive(true);
  BoardController& boardController = BoardController::GetSingleton(window.ui.graphicsScene, window.ui.graphicsView);

  // ChatController block
  ChatController& chatController = ChatController::GetSingleton();
  chatController.setInput(window.ui.chatViewInput);
  chatController.setOuptut(window.ui.chatViewOutput);
  chatController.setSendButton(window.ui.chatViewSend);

  // Slots for chatController
  QObject::connect(window.ui.chatViewInput, SIGNAL(textChanged(QString)), &chatController, SLOT(toggleButton(QString)));
  QObject::connect(window.ui.chatViewInput, SIGNAL(returnPressed()), &chatController, SLOT(lineEditReturn()));
  QObject::connect(window.ui.chatViewSend, SIGNAL(clicked()), &chatController,SLOT (sendButtonClicked()));

  //slots for boardController
  QObject::connect(window.ui.rectButton, SIGNAL(clicked()), &boardController, SLOT(SquareButtonClicked()));
  QObject::connect(window.ui.lineButton, SIGNAL(clicked()), &boardController, SLOT(LineButtonClicked()));
  QObject::connect(window.ui.textButton, SIGNAL(clicked()), &boardController, SLOT(TextButtonClicked()));
  QObject::connect(window.ui.ellipseButton, SIGNAL(clicked()), &boardController, SLOT(EllipseButtonClicked()));
  QObject::connect(window.ui.freehandButton, SIGNAL(clicked()), &boardController, SLOT(FreehandButtonClicked()));
  QObject::connect(window.ui.eraseButton, SIGNAL(clicked()), &boardController, SLOT(EraseButtonClicked()));
  QObject::connect(window.ui.moveButton, SIGNAL(clicked()), &boardController, SLOT(MoveButtonClicked()));
  QObject::connect(window.ui.selectButton, SIGNAL(clicked()), &boardController, SLOT(SelectButtonClicked()));

  QObject::connect(window.ui.actionSave_Session, SIGNAL(activated()), &boardController, SLOT(SaveSessionClicked()));
  QObject::connect(window.ui.actionResume_Session, SIGNAL(activated()), &boardController, SLOT(ResumeSessionClicked()));
  QObject::connect(window.ui.actionJoin_existing_session, SIGNAL(activated()), this, SLOT(OnJoinClicked()));
  QObject::connect(window.ui.actionStart_new_session, SIGNAL(activated()), this, SLOT(OnStartClicked()));
  QObject::connect(window.ui.actionExport_Canvas, SIGNAL (activated()), &boardController, SLOT(OnExportClicked()));
  QObject::connect(window.ui.actionUndo, SIGNAL(activated()), &boardController, SLOT(OnUndoClicked()));
  QObject::connect(window.ui.actionRedo, SIGNAL(activated()), &boardController, SLOT(OnRedoClicked()));
  QObject::connect(window.ui.actionHistory, SIGNAL(activated()), &Log::GetSingleton(), SLOT(OnHistoryClicked()));
  QObject::connect(window.ui.actionFast_connection, SIGNAL(activated()), &boardController, SLOT(FastConnectionClicked()));
  QObject::connect(window.ui.actionSlow_connection, SIGNAL(activated()), &boardController, SLOT(SlowConnectionClicked()));
  QObject::connect(window.ui.actionExit,SIGNAL(activated()),Tabula::GetSingleton().GetQApplication(), SLOT(quit()));
  window.resize(800, 600);
  window.show();
}

void GUI::OnJoinClicked()
{
  //make the join session dialog appear.
  joinSession.show();
}

void GUI::OnStartClicked()
{
  //make the star session dialog appear.
  startSession.show();
}
