/*
* ui_connect.h
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/

#ifndef __UI_CONNECT_H__
#define __UI_CONNECT_H__

//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QDialog>
#include <QtGui/QDialogButtonBox>
#include <QtGui/QLabel>
#include <QtGui/QLineEdit>
#include <QtGui/QPushButton>
//====================================================================================
// Project Includes
//====================================================================================

//====================================================================================
// Local Includes
//====================================================================================

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
QT_BEGIN_NAMESPACE

namespace Ui
{
  class StartConnection
  {
  public:
    QDialogButtonBox* buttonBox;
    QLineEdit* ipBox;
    QLineEdit* portBox;
    QLineEdit* usernameBox;
    QLineEdit* passwordBox;
    QLabel* ipLabel;
    QLabel* portLabel;
    QLabel* usernameLabel;
    QLabel* passwordLabel;
    StartConnection()
    {
      buttonBox = 0;
      ipBox = 0;
      portBox = 0;
      usernameBox = 0;
      passwordBox = 0;
      ipLabel = 0;
      portLabel = 0;
      usernameLabel = 0;
      passwordLabel = 0;
    }

    ~StartConnection()
    {
      delete buttonBox;
      delete ipBox;
      delete portBox;
      delete usernameBox;
      delete passwordBox;
      delete ipLabel;
      delete portLabel;
      delete usernameLabel;
      delete passwordLabel;
    }

    void Setup(QDialog* dialog, bool connecting = false)
    {
      if (dialog->objectName().isEmpty())
      {
        dialog->setObjectName(QString::fromUtf8("StartConnection"));
      }
      dialog->resize(320, 240);

      if(connecting)
      {
        dialog->setWindowTitle(QObject::trUtf8("Join Session"));
      }
      else
      {
        dialog->setWindowTitle(QObject::trUtf8("Start Session"));
      }

      buttonBox = new QDialogButtonBox(dialog);
      buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
      buttonBox->setGeometry(QRect(10, 200, 301, 32));
      buttonBox->setOrientation(Qt::Horizontal);
      buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

      if(connecting)
      {
        ipLabel = new QLabel(dialog);
        ipLabel->setObjectName(QString::fromUtf8("ipLabel"));
        ipLabel->setGeometry(QRect(20, 40, 60, 15));
        ipLabel->setText(QObject::trUtf8("IP Address:"));
        ipBox = new QLineEdit(dialog);
        ipBox->setObjectName(QString::fromUtf8("ipBox"));
        ipBox->setGeometry(QRect(80, 40, 100, 20));
      }

      portLabel = new QLabel(dialog);
      portLabel->setObjectName(QString::fromUtf8("portLabel"));
      portLabel->setGeometry(QRect(20, 80, 60, 15));
      portLabel->setText(QObject::trUtf8("Port:"));
      portBox = new QLineEdit(dialog);
      portBox->setObjectName(QString::fromUtf8("portBox"));
      portBox->setGeometry(QRect(80, 80, 100, 20));
      portBox->setText("3453");

      usernameLabel = new QLabel(dialog);
      usernameLabel->setObjectName(QString::fromUtf8("usernameLabel"));
      usernameLabel->setGeometry(QRect(20, 120, 60, 15));
      usernameLabel->setText(QObject::trUtf8("Username:"));
      usernameBox = new QLineEdit(dialog);
      usernameBox->setObjectName(QString::fromUtf8("usernameBox"));
      usernameBox->setGeometry(QRect(80, 120, 100, 20));

      passwordLabel = new QLabel(dialog);
      passwordLabel->setObjectName(QString::fromUtf8("passwordBox"));
      passwordLabel->setGeometry(QRect(20, 160, 60, 15));
      passwordLabel->setText(QObject::trUtf8("Password:"));
      passwordBox = new QLineEdit(dialog);
      passwordBox->setObjectName(QString::fromUtf8("passwordBox"));
      passwordBox->setGeometry(QRect(80, 160, 100, 20));
      passwordBox->setEchoMode(QLineEdit::Password);
      buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false); 
      dialog->setAttribute(Qt::WA_DeleteOnClose);
      QObject::connect(buttonBox, SIGNAL(accepted()), dialog, SLOT(accept()));
      QObject::connect(buttonBox, SIGNAL(rejected()), dialog, SLOT(reject()));
      QObject::connect(passwordBox, SIGNAL(textChanged (const QString&)),dialog,SLOT(textChang(const QString&)));
      QObject::connect(usernameBox, SIGNAL(textChanged (const QString&)),dialog,SLOT(textChang(const QString&)));
      QObject::connect(portBox, SIGNAL(textChanged (const QString&)),dialog,SLOT(textChang(const QString&)));
      dialog->setWindowFlags(Qt::WindowStaysOnTopHint);


      QMetaObject::connectSlotsByName(dialog);
    }

    inline int GetPort() const { return portBox->text().toInt(); }
    inline QByteArray GetIP() const { return ipBox->text().toUtf8(); }
    inline QByteArray GetUsername() const { return usernameBox->text().toUtf8(); }
    inline QByteArray GetPassword() const { return passwordBox->text().toUtf8(); }



  };
}

QT_END_NAMESPACE

#endif // __UI_CONNECT_H__
