/*
* ContextFreehand.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtGui/QGraphicsSceneMouseEvent>
#include <QtGui/QPolygonF>
#include <QtCore/QPointF>

//====================================================================================
// Project Includes
//====================================================================================
#include <iostream>
#include "log/draw.h"
#include "log/modify.h"
#include "DescPath.h"
#include "icontextcallback.h"
//====================================================================================
// Local Includes
//====================================================================================
#include "ContextFreehand.h"
#include "DGraphicsPathItem.h"
#include "Preprocessor.h"
//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------


ContextFreehand::ContextFreehand(void) : drawing(false), currentItem(0)
{
  this->preprocessor = NULL;
}

ContextFreehand::~ContextFreehand(void)
{
}

bool ContextFreehand::MousePressEvent(QGraphicsSceneMouseEvent *mouseEvent, Event*& newEvent)
{
  drawing = true;

  // Get position & add to point list
  std::vector<QPointF> points;
  points.push_back(mouseEvent->scenePos());
  currentItem = new DescPath(points, 0, true);
  newEvent = new TempDraw(currentItem);

  return true;
}

bool ContextFreehand::MouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent, QPointF& newPos, Event*& newEvent)
{
  if(drawing)
  {
    // Get & add to point list
    std::vector<QPointF> points = static_cast<DGraphicsPathItem*>(currentItem->GetFactory())->GetPoints();
    std::vector<QPointF> point;
    points.push_back(mouseEvent->scenePos());
    point.push_back(mouseEvent->scenePos());
    newEvent = new TempModify(new DescPath(point, 0, true), currentItem->GetFactory()->GetEvent());
  }

  return false;
}

bool ContextFreehand::MouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent, Event*& newEvent)
{
  drawing = false;
  
  // Creating the freehand
  std::vector<QPointF>& points = static_cast<DGraphicsPathItem*>(currentItem->GetFactory())->GetPoints();

  if(preprocessor)
  { 
    points = preprocessor->Execute(points);
  }

  newEvent = new Draw(new DescPath(points, 0, false));

  return false;
}

void ContextFreehand::setPreprocessor(Preprocessor * preprocessor)
{
  this->preprocessor = preprocessor;
}

void ContextFreehand::MousePressCallBack(iDGraphicsItem *item)
{
  item->GetCallback()->ClearSelection();
}

void ContextFreehand::MouseMoveCallBack(iDGraphicsItem *item)
{
}

void ContextFreehand::MouseReleaseCallBack(iDGraphicsItem *item)
{
  item->GetCallback()->ClearSelection();
}
