/*
* ContextLine.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtGui/QGraphicsSceneMouseEvent>
#include <QtGui/QGraphicsLineItem>

//====================================================================================
// Project Includes
//====================================================================================
#include <iostream>
#include "log/draw.h"
#include "log/modify.h"
#include "icontextcallback.h"

//====================================================================================
// Local Includes
//====================================================================================
#include "ContextLine.h"
#include "DGraphicsLineItem.h"
#include "DescLine.h"
//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------



ContextLine::ContextLine(void) : drawing(false), currentItem(0)
{
}

ContextLine::~ContextLine(void)
{
}

bool ContextLine::MousePressEvent(QGraphicsSceneMouseEvent *mouseEvent, Event*& newEvent)
{
  drawing = true;

  // Get start position
  QPointF pos( mouseEvent->buttonDownScenePos(mouseEvent->button()) );
  currentItemX = pos.x();
  currentItemY = pos.y();
  currentItemWidth = 0;
  currentItemHeight = 0;
  currentItem = new DescLine(currentItemX, currentItemY, currentItemWidth, currentItemHeight, 0, true);
  newEvent = new TempDraw(currentItem);

  return true;
}


bool ContextLine::MouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent, QPointF& newPos, Event*& newEvent)
{
  if(drawing)
  {
    // Update shape size
    QPointF pos(mouseEvent->lastScenePos());
    currentItemWidth = pos.x() - currentItemX;
    currentItemHeight = pos.y() - currentItemY;
    newEvent = new TempModify(new DescLine(currentItemX, currentItemY, currentItemWidth, currentItemHeight, 0, true), currentItem->GetFactory()->GetEvent());
  }

  return false;
}

bool ContextLine::MouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent, Event*& newEvent)
{
  drawing = false;

  // Finalise size
  QPointF pos(mouseEvent->lastScenePos());
  currentItemWidth = pos.x() - currentItemX;
  currentItemHeight = pos.y() - currentItemY;
  newEvent = new Draw(new DescLine(currentItemX, currentItemY, currentItemWidth, currentItemHeight, 0, false));

  return false;
}

void ContextLine::MousePressCallBack(iDGraphicsItem *item)
{
  item->GetCallback()->ClearSelection();
}

void ContextLine::MouseReleaseCallBack(iDGraphicsItem *item)
{
}

void ContextLine::MouseMoveCallBack(iDGraphicsItem *item)
{
  item->GetCallback()->ClearSelection();
}
