/*
* ContextMove.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QPointF>
#include <QtGui/QGraphicsSceneMouseEvent>
//====================================================================================
// Project Includes
//====================================================================================
#include <iostream>
//====================================================================================
// Local Includes
//====================================================================================
#include "ContextMove.h"
//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------


ContextMove::ContextMove(void) : drawing(false)
{
}

ContextMove::~ContextMove(void)
{
}

bool ContextMove::MousePressEvent(QGraphicsSceneMouseEvent *mouseEvent, Event*& newEvent)
{
  // Get start pos & current pos
  QPointF pos( QPointF(mouseEvent->buttonDownScenePos(mouseEvent->button())) );
  startX = pos.x();
  startY = pos.y();
  currentX = pos.x();
  currentY = pos.y();

  drawing = true;

  return false;
}
bool ContextMove::MouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent, QPointF& newPos, Event*& newEvent)
{
  if(drawing)
  {
    // Get the current mouse position, work out the difference since last time
    // and nudge the objects by that much.

    QPointF pos(mouseEvent->lastScenePos());
    qreal diffX = pos.x() - currentX;
    qreal diffY = pos.y() - currentY;
    currentX = pos.x();
    currentY = pos.y();

    newPos = QPointF(diffX, diffY);
    return true;
  }

  return false;
}
bool ContextMove::MouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent, Event*& newEvent)
{	
  this->drawing = false;
  return true;
}

void ContextMove::MousePressCallBack(iDGraphicsItem *item)
{
}

void ContextMove::MouseReleaseCallBack(iDGraphicsItem *item)
{
}

void ContextMove::MouseMoveCallBack(iDGraphicsItem *item)
{
}
