/*
* ContextRect.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtGui/QGraphicsSceneMouseEvent>
#include <QtGui/QGraphicsRectItem>

//====================================================================================
// Project Includes
//====================================================================================
#include "log/draw.h"
#include "log/modify.h"
#include <iostream>
#include "icontextcallback.h"
//====================================================================================
// Local Includes
//====================================================================================
#include "ContextRect.h"
#include "DGraphicsRectItem.h"
#include "DescRect.h"
//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------




ContextRect::ContextRect() : drawing(false), currentItem(0)
{
}

ContextRect::~ContextRect()
{
}

bool ContextRect::MousePressEvent(QGraphicsSceneMouseEvent *mouseEvent, Event*& newEvent)
{
  drawing = true;

  // Get start pos, size 0
  QPointF pos( mouseEvent->buttonDownScenePos(mouseEvent->button()) );
  currentItemX = pos.x();
  currentItemY = pos.y();
  currentItemWidth = 0;
  currentItemHeight = 0;
  currentItem = new DescRect(currentItemX, currentItemY, currentItemWidth, currentItemHeight, 0, true);
  newEvent = new TempDraw(currentItem);

  return true;
}


bool ContextRect::MouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent, QPointF& newPos, Event*& newEvent)
{
  if(drawing)
  {
    // Update size
    QPointF pos(mouseEvent->lastScenePos());
    currentItemWidth = (pos.x() - currentItemX);
    currentItemHeight = (pos.y() - currentItemY);
    newEvent = new TempModify(new DescRect(currentItemX, currentItemY, currentItemWidth, currentItemHeight, 0, true), currentItem->GetFactory()->GetEvent());
  }

  return false;
}

bool ContextRect::MouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent, Event*& newEvent)
{
  drawing = false;

  // Calc final size & create
  QPointF pos(mouseEvent->lastScenePos());
  currentItemWidth = (pos.x() - currentItemX);
  currentItemHeight = (pos.y() - currentItemY);
  newEvent = new Draw(new DescRect(currentItemX, currentItemY, currentItemWidth, currentItemHeight, 0, false));

  return false;
}

void ContextRect::MousePressCallBack(iDGraphicsItem *item)
{
  item->GetCallback()->ClearSelection();
}

void ContextRect::MouseReleaseCallBack(iDGraphicsItem *item)
{
}

void ContextRect::MouseMoveCallBack(iDGraphicsItem *item)
{
  item->GetCallback()->ClearSelection();
}
