/*
* DGraphicsEllipseItem.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtGui/QPen>
#include <QtGui/QColor>
#include <QtGui/QBrush>
#include <QtCore/QPointF>
//====================================================================================
// Project Includes
//====================================================================================
#include "icontext.h"
#include "icontextcallback.h"
#include <iostream>
#include "log/draw.h"
#include "log/modify.h"
#include "network/network.h"
//====================================================================================
// Local Includes
//====================================================================================
#include "DescEllipse.h"
#include "ResizeDialog.h"
#include "DGraphicsEllipseItem.h"
//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
typedef Modify ModifyEvent;


void DGraphicsEllipseItem::SetLock(bool lock)
{
  locked = lock;
}

bool DGraphicsEllipseItem::GetLock()
{
  return locked;
}

void DGraphicsEllipseItem::BringForward()
{
  setZValue(zValue()+1);
}

void DGraphicsEllipseItem::SendBack()
{
  setZValue(zValue()-1);
}

DGraphicsEllipseItem::DGraphicsEllipseItem(iContextCallback* callback) : callback(callback)
{
  // Set all selection flags
  setFlag(DGraphicsEllipseItem::ItemIsSelectable, true);
  setFlag(DGraphicsEllipseItem::ItemIgnoresTransformations, true);
  setFlag(DGraphicsEllipseItem::ItemIsFocusable, true);
  setAcceptDrops(true);
  setAcceptHoverEvents(true);
  setAcceptsHoverEvents(true);
  this->setBrush(QBrush(Qt::white));  // Paint colour
  setZValue(0);
  locked = false;
}

DGraphicsEllipseItem::~DGraphicsEllipseItem(void)
{
}

void DGraphicsEllipseItem::Modify(const iDesc* desc)
{
  const DescEllipse* descE = dynamic_cast<const DescEllipse*>(desc);
  if(descE)
  {
    // Update shape info
    locked = descE->GetLocked();
    setRect(0, 0, descE->GetWidth(), descE->GetHeight());

    // Update child details
    if( parentItem() )
      setPos( parentItem()->mapFromScene( QPointF( descE->GetX(), descE->GetY() ) ) );
    else
      setPos(descE->GetX(), descE->GetY());
    setZValue(descE->GetZOrder());
  }
}

iDesc* DGraphicsEllipseItem::GetDesc()
{
  return static_cast<iDesc*>(new DescEllipse(scenePos().x(), scenePos().y(), rect().width(), rect().height(), zValue(), locked));
}

void DGraphicsEllipseItem::Erase()
{
  QGraphicsItem *item = this;
  item->hide();
}

void DGraphicsEllipseItem::SetEvent(Draw* d)
{
  draw = d;
  draw->SetGraphicsItem(this);
}

void DGraphicsEllipseItem::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsEllipseItem::mousePressEvent(mouseEvent);
  callback->PressCallBack(this);
}
void DGraphicsEllipseItem::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsEllipseItem::mouseMoveEvent(mouseEvent);
  callback->MoveCallBack(this);
}
void DGraphicsEllipseItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsEllipseItem::mouseReleaseEvent(mouseEvent);
  callback->ReleaseCallBack(this);
}

void DGraphicsEllipseItem::hoverEnterEvent(QGraphicsSceneHoverEvent *sceneEvent)
{
  QAbstractGraphicsShapeItem *item = this;
  //save the current colour
  //set the new pen of your choice;
  item->setPen(QPen(QColor(255, 0, 0)));
}
void DGraphicsEllipseItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *sceneEvent)
{
  //restore the original colour
  QAbstractGraphicsShapeItem *item = this;
  //save the current colour
  //set the new pen of your choice;
  item->setPen(QPen(QColor(0, 0, 0)));
}

void DGraphicsEllipseItem::ResizeStart( bool sendTempEvents )
{
  // Start seending temp events
  this->sendTempEvents = sendTempEvents;

  // Create resize dialog
  ResizeDialog * resizeDialog = new ResizeDialog(this,this->rect().width(),this->rect().height(),1280,1024);

}
void DGraphicsEllipseItem::AdjustHorizontal(int value)
{
  // Update width
  QRectF r = rect();
  r.setWidth( value );
  setRect( r );

  if( sendTempEvents )
  {
    // Send temp modify event
    TempModify modify( GetDesc(), draw, true );
    modify.SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);
  }
}
void DGraphicsEllipseItem::AdjustVertical(int value)
{
  // Update height
  QRectF r = rect();
  r.setHeight( value );
  setRect( r );

  if( sendTempEvents )
  {
    // Send temp modify event
    TempModify modify( GetDesc(), draw, true );
    modify.SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);
  }
}

void DGraphicsEllipseItem::ResizeEnd(QDialog *dialog, int x, int y)
{
  // Create modify event
  ModifyEvent* modify = new ModifyEvent( GetDesc(), draw );
  Log::GetSingleton().Add(modify);  // Add to log
  modify->SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);  // Send over network
  dialog->close();  // Close dialog
}

