/*
* DGraphicsLineItem.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QPointF>
#include <QtGui/QPen>
#include <QtGui/QColor>
//====================================================================================
// Project Includes
//====================================================================================
#include <iostream>
#include "icontext.h"
#include "icontextcallback.h"
#include "log/draw.h"
#include "log/modify.h"
#include "network/network.h"
//====================================================================================
// Local Includes
//====================================================================================
#include "DGraphicsLineItem.h"
#include "DescLine.h"
#include "ResizeDialog.h"
//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
typedef Modify ModifyEvent;



void DGraphicsLineItem::SetLock(bool lock)
{
  locked = lock;
}

bool DGraphicsLineItem::GetLock()
{
  return locked;
}

void DGraphicsLineItem::BringForward()
{
  this->setZValue(this->zValue()+1);
}
void DGraphicsLineItem::SendBack()
{
  this->setZValue(this->zValue()-1);
}
DGraphicsLineItem::DGraphicsLineItem(iContextCallback* callback) : callback(callback)
{
  // Set all flags
  setFlag(DGraphicsLineItem::ItemIsSelectable, true);
  setFlag(DGraphicsLineItem::ItemIgnoresTransformations, true);
  setFlag(DGraphicsLineItem::ItemIsFocusable, true);
  setAcceptDrops(true);
  setAcceptHoverEvents(true);
  setAcceptsHoverEvents(true);
  setZValue(0);
  locked = false;
}

DGraphicsLineItem::~DGraphicsLineItem(void)
{
}

void DGraphicsLineItem::Modify(const iDesc* desc)
{
  const DescLine* descL = dynamic_cast<const DescLine*>(desc);
  if(descL)
  {
    // Update from modify descriptor
    locked = descL->GetLocked();
    setLine(0, 0, descL->GetWidth(), descL->GetHeight());
    if( parentItem() )
       // Update children
      setPos( parentItem()->mapFromScene( QPointF( descL->GetX(), descL->GetY() ) ) );
    else
      // Update self
      setPos(descL->GetX(), descL->GetY());
    setZValue(descL->GetZOrder());
  }
}

iDesc* DGraphicsLineItem::GetDesc()
{
  return static_cast<iDesc*>(new DescLine(scenePos().x(), scenePos().y(), line().x2(), line().y2(), zValue(), locked));
}

void DGraphicsLineItem::Erase()
{
  QGraphicsItem *item = this;
  item->hide();
}

void DGraphicsLineItem::SetEvent(Draw* d)
{
  draw = d;
  draw->SetGraphicsItem(this);
}

void DGraphicsLineItem::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsLineItem::mousePressEvent(mouseEvent);
  callback->PressCallBack(this);
}

void DGraphicsLineItem::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsLineItem::mouseMoveEvent(mouseEvent);
  callback->MoveCallBack(this);
}
void DGraphicsLineItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsLineItem::mouseReleaseEvent(mouseEvent);
  callback->ReleaseCallBack(this);
}

void DGraphicsLineItem::hoverEnterEvent(QGraphicsSceneHoverEvent *sceneEvent)
{
  //	QAbstractGraphicsShapeItem *item = this;
  //save the current colour
  //set the new pen of your choice;
  this->setPen(QPen(QColor(255, 0, 0)));
}
void DGraphicsLineItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *sceneEvent)
{
  //restore the original colour
  //QAbstractGraphicsShapeItem *item = this;
  //save the current colour
  //set the new pen of your choice;
  this->setPen(QPen(QColor(0, 0, 0)));
}


void DGraphicsLineItem::ResizeStart( bool sendTempEvents )
{
  // Start sending temp events
  this->sendTempEvents = sendTempEvents;

  // Show dialog
  ResizeDialog * resizeDialog = new ResizeDialog(this,this->x(),this->y(),1280,1024);
}
void DGraphicsLineItem::AdjustHorizontal(int value)
{
  // Update width
  QPointF p = line().p2();
  p.setX( value );
  line().setP2( p );

  if( sendTempEvents )
  {
    // Create and send temp event
    TempModify modify( GetDesc(), draw, true );
    modify.SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);
  }
}
void DGraphicsLineItem::AdjustVertical(int value)
{
  // Update height
  QPointF p = line().p2();
  p.setY( value );
  line().setP2( p );

  if( sendTempEvents )
  {
    // Create and send temp event
    TempModify modify( GetDesc(), draw, true );
    modify.SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);
  }
}
void DGraphicsLineItem::ResizeEnd(QDialog *dialog, int x, int y)
{
  // Create final modify event
  ModifyEvent* modify = new ModifyEvent( GetDesc(), draw );
  Log::GetSingleton().Add(modify);  // Add to log
  modify->SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);  // Send
  dialog->close();  // Close dialog
}
