/*
* DGraphicsPathItem.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtGui/QPen>
#include <QtGui/QColor>
//====================================================================================
// Project Includes
//====================================================================================
#include <iostream>
#include "log/draw.h"
//====================================================================================
// Local Includes
//====================================================================================
#include "DGraphicsPathItem.h"
#include "icontext.h"
#include "icontextcallback.h"
#include "DescPath.h"
#include "ResizeDialog.h"
//------------------------------------------------------------------------------------
// Forward Declarations
//------------------------------------------------------------------------------------

// This class handles the freehand drawing.  It records a path of points 
// that closely but not perfectly match the mouse movement.

void DGraphicsPathItem::SetLock(bool lock)
{
  locked = lock;
}

bool DGraphicsPathItem::GetLock()
{
  return locked;
}

void DGraphicsPathItem::BringForward()
{
  setZValue(zValue()+1);
}
void DGraphicsPathItem::SendBack()
{
  setZValue(zValue()-1);
}

// Sets up a freehand item
DGraphicsPathItem::DGraphicsPathItem(iContextCallback* callback) : callback(callback)
{
  setFlag(DGraphicsPathItem::ItemIsSelectable, true);
  setFlag(DGraphicsPathItem::ItemIgnoresTransformations, true);
  setFlag(DGraphicsPathItem::ItemIsFocusable, true);
  setZValue(0);
  locked = false;
}

DGraphicsPathItem::~DGraphicsPathItem(void)
{
}

// Describes behaviour for a modification to a freehand line.
// Also describes how to draw a line.
void DGraphicsPathItem::Modify(const iDesc* desc)
{
  const DescPath* descP = dynamic_cast<const DescPath*>(desc);
  if(descP)
  {
    locked = descP->GetLocked();

    setZValue(descP->GetZOrder());
    const std::vector<QPointF>& nPoints = descP->GetPoints();

    // This part adds points to the array as they are drawn.
    for(size_t i=0; i<nPoints.size(); i++)
    {	
      points.push_back(nPoints[i]);
      if( parentItem() )
        points[points.size()-1] = parentItem()->mapFromScene( points[points.size()-1] );
      QPainterPath p = path();
      p.lineTo(points[points.size()-1]);
      setPath(p);
    }
  }
}

iDesc* DGraphicsPathItem::GetDesc()
{
  std::vector<QPointF> movePoints;
  return static_cast<iDesc*>(new DescPath(movePoints, zValue(), locked));
}

void DGraphicsPathItem::Erase()
{
  hide();
}

void DGraphicsPathItem::SetEvent(Draw* d)
{
  draw = d;
  draw->SetGraphicsItem(this);
}

void DGraphicsPathItem::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsPathItem::mousePressEvent(mouseEvent);
  callback->PressCallBack(this);
}
void DGraphicsPathItem::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsPathItem::mouseMoveEvent(mouseEvent);
  callback->MoveCallBack(this);
}
void DGraphicsPathItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsPathItem::mouseReleaseEvent(mouseEvent);
  callback->ReleaseCallBack(this);
}
void DGraphicsPathItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *sceneEvent)
{
  //QGraphicsPathItem::hoverLeaveEvent(sceneEvent);
  std::cout << "hello";
  //QAbstractGraphicsShapeItem *item = this;
  //save the current colour
  //set the new pen of your choice;
  this->setPen(QPen(QColor(0, 0, 0)));
}
void DGraphicsPathItem::hoverEnterEvent(QGraphicsSceneHoverEvent *sceneEvent)
{
  //QGraphicsPathItem::hoverEnterEvent(sceneEvent);
  std::cout << "hello";
  //save the current colour
  //set the new pen of your choice;

  this->setPen(QPen(QColor(255, 0, 0)));
}

void DGraphicsPathItem::ResizeStart( bool sendTempEvents )
{
  //ResizeDialog * resizeDialog = new ResizeDialog(this,this->rect().width(),this->rect().height(),1280,1024);
}
void DGraphicsPathItem::AdjustHorizontal(int value)
{
}
void DGraphicsPathItem::AdjustVertical(int value)
{
}
void DGraphicsPathItem::ResizeEnd(QDialog *dialog, int x, int y)
{
}
