/*
* DGraphicsRectItem.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/

//====================================================================================
// QT Includes
//====================================================================================
#include <QtGui/QBrush>
#include <QtCore/QPointF>
#include <QtGui/QPen>
#include <QtGui/QColor>
#include <QtGui/QGraphicsSceneMouseEvent>
//====================================================================================
// Project Includes
//====================================================================================
#include <iostream>
#include "network/network.h"
#include "log/modify.h"
#include "log/draw.h"
//====================================================================================
// Local Includes
//====================================================================================
#include "DGraphicsRectItem.h"
#include "icontext.h"
#include "icontextcallback.h"
#include "DescRect.h"
#include "ResizeDialog.h"
//------------------------------------------------------------------------------------
// Forward Declarations
//------------------------------------------------------------------------------------

typedef Modify ModifyEvent;


void DGraphicsRectItem::SetLock(bool lock)
{
  locked = lock;
}

bool DGraphicsRectItem::GetLock()
{
  return locked;
}

void DGraphicsRectItem::BringForward()
{
  //this->setZValue(this->zValue()+1);
  //TODO: create an event as if the object had moved noting the z value in the descriptor.
}
void DGraphicsRectItem::SendBack(){
  //this->setZValue(this->zValue()-1);

  //TODO: mike create an event as if the object had moved noting the z value in the descriptor.
}

// Sets up the Rectangle item, initial settings such as making it selectable,
// making it focusable are set up.
DGraphicsRectItem::DGraphicsRectItem(iContextCallback* callback) : callback(callback)
{
  setFlag(DGraphicsRectItem::ItemIsSelectable, true);
  setFlag(DGraphicsRectItem::ItemIgnoresTransformations, true);
  setFlag(DGraphicsRectItem::ItemIsFocusable, true);
  setAcceptDrops(true);
  setAcceptHoverEvents(true);
  setAcceptsHoverEvents(true);
  this->setBrush(QBrush(Qt::white));
  setZValue(0);
  locked = false;
}

DGraphicsRectItem::~DGraphicsRectItem(void)
{
}

void DGraphicsRectItem::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsRectItem::mousePressEvent(mouseEvent);
  callback->PressCallBack(this);
}
void DGraphicsRectItem::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsRectItem::mouseMoveEvent(mouseEvent);
  callback->MoveCallBack(this);
}
void DGraphicsRectItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
  QGraphicsRectItem::mouseReleaseEvent(mouseEvent);
  callback->ReleaseCallBack(this);
}

void DGraphicsRectItem::hoverEnterEvent(QGraphicsSceneHoverEvent *sceneEvent)
{
  QAbstractGraphicsShapeItem *item = this;
  //save the current colour
  //set the new pen of your choice;
  item->setPen(QPen(QColor(255, 0, 0)));
}
void DGraphicsRectItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *sceneEvent)
{
  //restore the original colour
  QAbstractGraphicsShapeItem *item = this;
  //save the current colour
  //set the new pen of your choice;
  item->setPen(QPen(QColor(0, 0, 0)));
}

// On a modification, changes item values (width, height and z-order)
void DGraphicsRectItem::Modify(const iDesc* desc)
{
  const DescRect* descR = dynamic_cast<const DescRect*>(desc);
  if(descR)
  {
    locked = descR->GetLocked();

    setRect(0, 0, descR->GetWidth(), descR->GetHeight());
    if( parentItem() )
      setPos( parentItem()->mapFromScene( QPointF( descR->GetX(), descR->GetY() ) ) );
    else
      setPos(descR->GetX(), descR->GetY());
    setZValue(descR->GetZOrder());
  }
}

iDesc* DGraphicsRectItem::GetDesc()
{
  return static_cast<iDesc*>(new DescRect(scenePos().x(), scenePos().y(), rect().width(), rect().height(), zValue(), locked));
}

void DGraphicsRectItem::Erase()
{
  QGraphicsItem *item = this;
  item->hide();
}

void DGraphicsRectItem::SetEvent(Draw* d)
{
  draw = d;
  draw->SetGraphicsItem(this);
}


void DGraphicsRectItem::ResizeStart( bool sendTempEvents )
{
  this->sendTempEvents = sendTempEvents;
  ResizeDialog * resizeDialog = new ResizeDialog(this,this->rect().width(),this->rect().height(),1280,1024);
}
void DGraphicsRectItem::AdjustHorizontal(int value)
{
  QRectF r = rect();
  r.setWidth( value );
  setRect( r );

  if( sendTempEvents )
  {
    TempModify modify( GetDesc(), draw, true );
    modify.SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);
  }
}
void DGraphicsRectItem::AdjustVertical(int value)
{
  QRectF r = rect();
  r.setHeight( value );
  setRect( r );

  if( sendTempEvents )
  {
    TempModify modify( GetDesc(), draw, true );
    modify.SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);
  }
}
void DGraphicsRectItem::ResizeEnd(QDialog *dialog, int x, int y)
{
  ModifyEvent* modify = new ModifyEvent( GetDesc(), draw );
  Log::GetSingleton().Add(modify);
  modify->SendEvent(Network::GetSingletonPtr(), MEDIUM_PRIORITY, 0);
  dialog->close();
}

