/*
* DescDeserialiser.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/

//====================================================================================
// QT Includes
//====================================================================================
#include <QtXml/QXmlStreamReader>

//====================================================================================
// Project Includes
//====================================================================================
#include "idesc.h"

//====================================================================================
// Local Includes
//====================================================================================
#include "DescEllipse.h"
#include "DescLine.h"
#include "DescRect.h"
#include "DescText.h"
#include "DescPath.h"
#include "DescDeserialiser.h"

//------------------------------------------------------------------------------------
// Forward Declarations
//------------------------------------------------------------------------------------

iDesc* DescDeserialiser::Deserialise( QXmlStreamReader& xml )
{
  // Check we're dealing with correct XML tag
  Q_ASSERT( xml.isStartElement() && xml.name() == "desc" );
  QStringRef type = xml.attributes().value( "type" );

  // Get type from XML & construct correct descriptor
  if( type == "ellipse" )
    return new DescEllipse( xml );
  else if( type == "line" )
    return new DescLine( xml );
  else if( type == "rect" )
    return new DescRect( xml );
  else if( type == "text" )
    return new DescText( xml );
  else if( type == "freehand" )
    return new DescPath( xml );
  else
    return NULL;
}

