/*
* DescEllipse.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtXml/QXmlStreamReader>
//====================================================================================
// Project Includes
//====================================================================================
#include "raknet/BitStream.h"
#include "log/draw.h"
//====================================================================================
// Local Includes
//====================================================================================
#include "DescEllipse.h"
#include "DGraphicsEllipseItem.h"

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
using namespace RakNet;

DescEllipse::DescEllipse(qreal x, qreal y, qreal width, qreal height, qreal zOrder, bool locked)
: DescGraphic(x, y, width, height, zOrder, locked), factory(0)
{
}

DescEllipse::DescEllipse(BitStream& bs) : DescGraphic(bs), factory(0)
{
}

DescEllipse::DescEllipse( QXmlStreamReader& xml ) : DescGraphic( xml ), factory(0)
{
  // Keep parsing XML to end for elipse
  while( !xml.atEnd() && !xml.isEndElement() )
    xml.readNext();
}

DescEllipse::~DescEllipse(void)
{
}

void DescEllipse::Serialise(RakNet::BitStream &bs) const
{
  // Add to bitstream & serialise super
  bs.WriteCompressed((iDesc::DescType)Ellipse);
  DescGraphic::Serialise(bs);
}

void DescEllipse::Serialise(QXmlStreamWriter& xml) const
{
  // Create XML tag & populate attribs
  xml.writeStartElement( "desc" );
  xml.writeAttribute( "type", "ellipse" );

  // Serialise super
  DescGraphic::Serialise(xml);

  xml.writeEndElement();
}

iDGraphicsItem* DescEllipse::GetFactory(iContextCallback* callback, Draw* draw)
{
  if(!factory)
  {
    // Factory to create ellipse
    factory = new DGraphicsEllipseItem(callback);
    factory->setPos(x, y);
    factory->setRect(0, 0, width, height);
    factory->setZValue(zOrder);
    factory->SetEvent(draw);
  }

  factory->setSelected(false);
  return factory;
}
