/*
* DescLine.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtXml/QXmlStreamReader>
//====================================================================================
// Project Includes
//====================================================================================
#include "raknet/BitStream.h"
#include "log/draw.h"
//====================================================================================
// Local Includes
//====================================================================================
#include "DescLine.h"
#include "DGraphicsLineItem.h"
//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
using namespace RakNet;

DescLine::DescLine(qreal x, qreal y, qreal width, qreal height, qreal zOrder, bool locked)
: DescGraphic(x, y, width, height, zOrder, locked), factory(0)
{
}

DescLine::DescLine(BitStream& bs) : DescGraphic(bs), factory(0)
{
}

DescLine::DescLine( QXmlStreamReader& xml ) : DescGraphic( xml ), factory(0)
{
  // Parse XML till end
  while( !xml.atEnd() && !xml.isEndElement() )
    xml.readNext();
}

DescLine::~DescLine(void)
{
}

void DescLine::Serialise(RakNet::BitStream &bs) const
{
  // Write to BitStream, call super
  bs.WriteCompressed((iDesc::DescType)Line);
  DescGraphic::Serialise(bs);
}

void DescLine::Serialise(QXmlStreamWriter& xml) const
{
  // Write line to XML
  xml.writeStartElement( "desc" );
  xml.writeAttribute( "type", "line" );
  DescGraphic::Serialise(xml);
  xml.writeEndElement();
}

iDGraphicsItem* DescLine::GetFactory(iContextCallback* callback, Draw* draw)
{
  if(!factory)
  {
    // Factory to create line
    factory = new DGraphicsLineItem(callback);
    factory->setPos(x, y);
    factory->setLine(0, 0, width, height);
    factory->setZValue(zOrder);
    factory->SetEvent(draw);
  }

  factory->setSelected(false);
  return factory;
}
