#pragma once
/*
* DescLine.h
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Dan Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QtGlobal>
#include <QtCore/QPointF>
//====================================================================================
// Project Includes
//====================================================================================
#include <vector>
#include "idesc.h"
//====================================================================================
// Local Includes
//====================================================================================

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
class DGraphicsPathItem;
class QXmlStreamReader;

namespace RakNet
{
  class BitStream;
}

class DescPath : public iDesc
{
public:
  DescPath(std::vector<QPointF> points, short zOrder, bool locked);
  DescPath(RakNet::BitStream& bs);
  DescPath(QXmlStreamReader& xml);
  ~DescPath(void);

  virtual void Serialise(RakNet::BitStream& bs) const;
  virtual void Serialise(QXmlStreamWriter& xml) const;
  virtual iDGraphicsItem* GetFactory(iContextCallback* callback, Draw* draw);
  const std::vector<QPointF>& GetPoints() const { return points; }
  inline short GetZOrder() const { return zOrder; }
  inline short GetLocked() const { return locked; }
  virtual inline QString GetStringDesc() const { return QString( "freehand" ); }

private:
  DGraphicsPathItem* factory;
  std::vector<QPointF> points;
  short zOrder;
  bool locked;
};
