/*
* DescRect.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtGui/QTransform>
#include <QtXml/QXmlStreamReader>

//====================================================================================
// Project Includes
//====================================================================================
#include "raknet/BitStream.h"
#include "log/draw.h"
//====================================================================================
// Local Includes
//====================================================================================
#include "DescRect.h"
#include "DGraphicsRectItem.h"
//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
using namespace RakNet;

DescRect::DescRect(qreal x, qreal y, qreal width, qreal height, qreal zOrder, bool locked)
: DescGraphic(x, y, width, height, zOrder, locked), factory(0)
{
}

DescRect::DescRect(BitStream& bs) : DescGraphic(bs), factory(0)
{
}

DescRect::DescRect( QXmlStreamReader& xml ) : DescGraphic( xml ), factory(0)
{
  // Parse all XML
  while( !xml.atEnd() && !xml.isEndElement() )
    xml.readNext();
}

DescRect::~DescRect(void)
{
}

void DescRect::Serialise(RakNet::BitStream &bs) const
{
  // Write to BitStream, call super
  bs.WriteCompressed((iDesc::DescType)Rect);
  DescGraphic::Serialise(bs);
}

void DescRect::Serialise(QXmlStreamWriter& xml) const
{
  // Write rect to XML, call super
  xml.writeStartElement( "desc" );
  xml.writeAttribute( "type", "rect" );
  DescGraphic::Serialise(xml);
  xml.writeEndElement();
}

iDGraphicsItem* DescRect::GetFactory(iContextCallback* callback, Draw* draw)
{
  if(!factory)
  {
    // Create rectangle on board
    factory = new DGraphicsRectItem(callback);
    factory->setPos(x, y);
    factory->setRect(0, 0, width, height);
    factory->setZValue(zOrder);
    factory->SetEvent(draw);
  }

  factory->setSelected(false);
  return factory;
}
