/*
* DescText.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QString>
#include <QtXml/QXmlStreamReader>
//====================================================================================
// Project Includes
//====================================================================================
#include "raknet/BitStream.h"
#include "raknet/StringCompressor.h"
#include "log/draw.h"
//====================================================================================
// Local Includes
//====================================================================================
#include "DescText.h"
#include "DGraphicsTextItem.h"
//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
using namespace RakNet;

DescText::DescText(const QString& text, qreal x, qreal y, qreal width, qreal zOrder, bool locked)
: DescGraphic(x, y, width, 0, zOrder, locked), text(text), factory(0)
{
}

DescText::DescText(BitStream& bs) : DescGraphic(bs), factory(0)
{
  // Read length of text to string
  size_t length;
  bs.ReadCompressed( length );
  char* buf = new char[length];

  // Decode compression
  stringCompressor->DecodeString(buf, (int)length, &bs);

  // Set local & cleanup
  text = QString( buf );
  delete buf;
}

DescText::DescText( QXmlStreamReader& xml ) : DescGraphic( xml ), factory(0)
{
  // Read XML, check for text, set local
  xml.readNext();
  Q_ASSERT( xml.isCharacters() );
  text = xml.text().toString();

  xml.readNext();
  Q_ASSERT( xml.isEndElement() );
}

DescText::~DescText(void)
{
}

void DescText::Serialise(RakNet::BitStream &bs) const
{
  // Write desc to BitStream, call super
  bs.WriteCompressed((iDesc::DescType)Text);
  DescGraphic::Serialise(bs);

  // Convert to UTF8
  QByteArray buf = text.toUtf8();
  bs.WriteCompressed( (size_t) ( buf.length()+1 ) );

  // Compress str & write
  stringCompressor->EncodeString( buf, buf.length()+1, &bs );
}

void DescText::Serialise(QXmlStreamWriter& xml) const
{
  // Write XML descriptor
  xml.writeStartElement( "desc" );
  xml.writeAttribute( "type", "text" );
  DescGraphic::Serialise(xml);

  // Write string
  xml.writeCharacters( text );

  // End
  xml.writeEndElement();
}

iDGraphicsItem* DescText::GetFactory(iContextCallback* callback, Draw* draw)
{
  if(!factory)
  {
    // Create text item
    factory = new DGraphicsTextItem(text, callback);
    factory->setPos(x, y);
    factory->setTextWidth(width);
    factory->setZValue(zOrder);
    factory->SetEvent(draw);
  }

  return factory;
}
