/*
* ResizeDialog.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/

//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QDialog>
#include <QtGui/QPushButton>
#include <QtGui/QSlider>
//====================================================================================
// Project Includes
//====================================================================================

//====================================================================================
// Local Includes
//====================================================================================
#include "ResizeDialog.h"
//------------------------------------------------------------------------------------
// Forward Declarations
//------------------------------------------------------------------------------------


// creates the resize dialog that pops up when selected from the right click menu
ResizeDialog::ResizeDialog(iDGraphicsItem *item, int horizontal, int vertical, int maxH, int maxV)
{
  // if (ResizeClass->objectName().isEmpty())
  this->setObjectName(QString::fromUtf8("ResizeClass"));
  this->item = item;
  this->resize(185, 205);
  this->setMaximumSize(QSize(185, 205));
  this->setSizeGripEnabled(false);
  this->setModal(false);

  buttonResizeDone = new QPushButton(this);
  buttonResizeDone->setObjectName(QString::fromUtf8("buttonResizeDone"));
  buttonResizeDone->setGeometry(QRect(60, 180, 75, 23));
  horizontalSlider = new QSlider(this);
  horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
  horizontalSlider->setGeometry(QRect(0, 160, 160, 21));
  horizontalSlider->setOrientation(Qt::Horizontal);
  horizontalSlider->setMaximum(maxH);
  horizontalSlider->setValue(horizontal);
  verticalSlider = new QSlider(this);
  verticalSlider->setObjectName(QString::fromUtf8("verticalSlider"));
  verticalSlider->setGeometry(QRect(160, 0, 21, 160));
  verticalSlider->setOrientation(Qt::Vertical);
  verticalSlider->setInvertedAppearance(true);
  verticalSlider->setInvertedControls(false);
  verticalSlider->setMaximum(maxV);
  verticalSlider->setValue(vertical);
  retranslateUi();
  setAttribute(Qt::WA_DeleteOnClose);
  show();
  // connect the signals from the sliders and button in resize dialog to their slots
  QObject::connect(this->verticalSlider,SIGNAL(valueChanged (int)),this,SLOT(AdjustVertical(int)));
  QObject::connect(this->horizontalSlider,SIGNAL(valueChanged (int)),this,SLOT(AdjustHorizontal(int)));
  QObject::connect(this->buttonResizeDone,SIGNAL(clicked()),this,SLOT(ResizeEnd()));
}

// resize dialog destructor
ResizeDialog::~ResizeDialog(void)
{
}

// Qt generated code.
void ResizeDialog::retranslateUi()
{
  this->setWindowTitle(QApplication::translate("ResizeClass", "Resize", 0, QApplication::UnicodeUTF8));
  this->setWindowOpacity(0.5);
  this->setWindowFlags(Qt::FramelessWindowHint| Qt::WindowStaysOnTopHint);
  //this->
  buttonResizeDone->setText(QApplication::translate("ResizeClass", "Finished!", 0, QApplication::UnicodeUTF8));
  //Q_UNUSED(ResizeClass);
} // retranslateUi

// passes the adjusted size of the item so that resizing can be
// seen live
void ResizeDialog::AdjustHorizontal(int value)
{
  this->item->AdjustHorizontal(value);
}

// same functionality os AdjustHorizontal above but for the vertical
// element of the item
void ResizeDialog::AdjustVertical(int value)
{
  this->item->AdjustVertical(value);
}

// Captures the final values for the horizontal and vertical size 
// when the dialog is closed
void ResizeDialog::ResizeEnd()
{
  this->item->ResizeEnd(this,this->horizontalSlider->value(),this->verticalSlider->value());
}
