/*
* delete.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/

//====================================================================================
// QT Includes
//====================================================================================
#include <QtXml/QXmlStreamWriter>
#include <QtXml/QXmlStreamReader>
//====================================================================================
// Project Includes
//====================================================================================
#include "network/messageids.h"
#include "raknet/BitStream.h"
#include "ilogcallback.h"
#include "idesc.h"

//====================================================================================
// Local Includes
//====================================================================================
#include "delete.h"
#include "draw.h"
//------------------------------------------------------------------------------------
// Forward Declarations
//------------------------------------------------------------------------------------

iLogCallback* Delete::callback = NULL;


Delete::Delete(Draw* drawEvent, bool isToBeLogged)
: Event(isToBeLogged), draw(drawEvent)
{}

TempDelete::TempDelete(Draw* drawEvent)
: Delete(drawEvent, false)
{
}

Delete::Delete( RakNet::BitStream& bs, const iSession* session )
: Event( bs, session ), draw( (Draw*) Log::GetSingleton().DeserializeEventPointer( bs ) ) /// deserialise recursively
{
}

Delete::~Delete()
{}

const Draw* Delete::GetDraw() const
{
  return draw;
}

void Delete::Execute() const
{
  if( callback )
    callback->DeleteEvent(*this);
}

void Delete::SendEvent(iNetwork* network, PacketPriority priority, SystemAddress* address)
{
  RakNet::BitStream bs;
  Serialise(bs);
  network->SendBitStream(bs, priority, RELIABLE_ORDERED, 2, address);
}

void Delete::Serialise( RakNet::BitStream& bs ) const
{
  bs.Write((MessageID)ID_DELETE_EVENT);
  bs.Write((unsigned char)RELIABLE_ORDERED);
  bs.Write((char)2);

  Event::Serialise( bs );
  draw->GetTimestamp().Serialise( bs );
}

void Delete::Serialise( QXmlStreamWriter& xml ) const
{
  xml.writeStartElement( "delete" );

  draw->GetTimestamp().Serialise( xml );

  Event::Serialise( xml );

  xml.writeEndElement();
}

Delete::Delete( QXmlStreamReader& xml, const iSession* session )
{
  Q_ASSERT( xml.isStartElement() && xml.name() == "delete" );

	// parse nested items
  while( !xml.atEnd() )
  {
    xml.readNext();

    if( xml.isEndElement() )
      break;

    if( xml.isStartElement() )
    {
			// parse inherited event
      if( xml.name() == "event" )
      {
        Event::Deserialise( xml, session );
      }
			// point to proper draw event again
      else if( xml.name() == "timestamp" )
      {
        Timestamp ts( xml );
        draw = (Draw*) Log::GetSingleton().FindEvent( ts );
      }
    }

  }
}

void Delete::Undo()
{
  draw->Redo();
}

void Delete::Redo()
{
  draw->Undo();
}

QString Delete::GetStringDesc() const
{
  return QString( "delete " ) + draw->GetDesc()->GetStringDesc();
}

