/*
* modify.h
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
#ifndef __MODIFY_H__
#define __MODIFY_H__

//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QPoint>

//====================================================================================
// Project Includes
//====================================================================================

//====================================================================================
// Local Includes
//====================================================================================
#include "event.h"

//------------------------------------------------------------------------------------
// Forward Declarations
//------------------------------------------------------------------------------------
class Draw;
namespace RakNet
{
  class BitStream;
}
class QXmlStreamWriter;
class QXmlStreamReader;
struct iDesc;
struct iLogCallback;
struct iSession;

class Modify : public Event
{
public:
	/**
	 * Registers the callback which will be called on Execute()
	 * @arguments cbObject Callback to be registered.
	 */
  static void RegisterCallback(iLogCallback* cbObject)
  {
    callback = cbObject;
  }

	/**
	 * Create an event which will cause the passed draw event to be modified by the specified descriptor.
	 * @argument desc The changes to be done.
	 * @argument drawEvent The shape on the screen to be hidden.
	 * @argument isToBeLogged If set to true this event would not be stored in the log though it is added.
	 */
  Modify(iDesc* desc, const Draw* drawEvent, bool isToBeLogged = true, bool hasDrawEvent = false);
  Modify(QPointF& point, const Draw* drawEvent, bool isToBeLogged = true);
  Modify(RakNet::BitStream& bs, const iSession* session);
  Modify(QXmlStreamReader& xml, const iSession* session);
  virtual ~Modify();

  const Draw* GetDraw() const;
  inline const iDesc* GetDesc() const { return desc; }
  inline QPointF GetMove() const { return point; }
  void Execute() const;

  virtual void SendEvent(iNetwork* network, PacketPriority priority, SystemAddress* address);

  virtual void Serialise(QXmlStreamWriter& xml) const;

  virtual void Undo();
  virtual void Redo() { Undo(); }
  inline void SetOldState(iDesc* d) { oldState = d; }

  virtual QString GetStringDesc() const;

protected:
  virtual void Serialise(RakNet::BitStream& bs) const;

private:
  static iLogCallback* callback;

  iDesc* desc;
  QPointF point;
  const Draw* draw;
  iDesc* oldState;
  bool moving;
};

class TempModify : public Modify
{
public:
  TempModify(iDesc* desc, const Draw* drawEvent, bool resize = false);
  TempModify(QPointF& point, const Draw* drawEvent);
  virtual ~TempModify() {}
};

#endif // __MODIFY_H__
