/*
* logger.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/

//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QString>

//====================================================================================
// Project Includes
//====================================================================================
#include <iostream>
#include <fstream>
#include <string>
#include <list>
#include <ctime>
#include <QtGui/QErrorMessage>
//====================================================================================
// Local Includes
//====================================================================================
#include "logger.h"

//------------------------------------------------------------------------------------
// Forward Declarations
//------------------------------------------------------------------------------------


using namespace std;


Logger* Logger::singleton = NULL;


Logger::Logger()
{}

Logger::~Logger()
{
  for( list<ostream*>::iterator oit = toFree.begin(); oit != toFree.end(); ++oit )
    delete *oit;
}

void Logger::add( ostream& outstream, int verbosityLevel )
{
  out.push_back( Output( outstream, verbosityLevel ) );
}

void Logger::add( const string& filename, int verbosityLevel )
{
  ofstream* outstream = new ofstream( filename.c_str() );
  toFree.push_back( outstream );
  out.push_back( Output( *outstream, verbosityLevel ) );
}

void Logger::log( int verbosityLevel, string message )
{
  string newMessage( getTimeStamp() + " " + message );
  for( list<Output>::iterator oit = out.begin(); oit != out.end(); ++oit )
  {
    oit->log( verbosityLevel, newMessage );
  }

  if (verbosityLevel < 10)
  {
    QErrorMessage *e = new QErrorMessage();
    e->setWindowFlags(Qt::WindowStaysOnTopHint);
    e->setAttribute(Qt::WA_DeleteOnClose);
    e->showMessage(QString(message.c_str()));
  }
}

void Logger::log( int verbosityLevel, QString message )
{
  log( verbosityLevel, message.toAscii().constData() );
}

void Logger::log( int verbosityLevel, const char* message )
{
  log( verbosityLevel, string( message ) );
}

const int Logger::timeStampLength = 30;
string Logger::getTimeStamp()
{
  char buf[timeStampLength];
  time_t timestamp;

  time( &timestamp );
  strftime( buf, timeStampLength-1, "[%d.%m.%Y %H:%M:%S]", localtime( &timestamp ) );
  return string( buf );
}

Logger::Output::Output( ostream& outstream, int verbosityLevel )
: verbosity( verbosityLevel ), stream( outstream )
{}

Logger::Output::~Output()
{
  //  stream.close();
}

void Logger::Output::log( int verbosityLevel, string message )
{
  if( verbosity >= verbosityLevel )
    stream << message << endl;
}
