/*
* session.cpp
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/

//====================================================================================
// QT Includes
//====================================================================================

//====================================================================================
// Project Includes
//====================================================================================
#include <QtCore/QAbstractItemModel>
#include <QtCore/QModelIndex>
#include <QtCore/QVariant>
//====================================================================================
// Local Includes
//====================================================================================
#include "session.h"
#include "raknet/BitStream.h"

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------
using namespace std;

int Session::rowCount ( const QModelIndex & parent) const
{
  //required override for implementing qabstractlistmodel
  return (int)sessionMembers.size();
}
QVariant Session::data(const QModelIndex & index, int role) const
{
  //required override for implementing qabstractlistmodel
  if((index.isValid()) && (role == Qt::DisplayRole)) return QString(sessionMembers[index.row()]->GetUsername()); else return QVariant();
}

void Session::AddMember(Person* person)
{
  sessionMembers.push_back(person);

  // Update the sessionView;
  reset();
}



bool Session::RemoveMember(const Person& person)
{
  unsigned int pos = FindMember(person);
  if(pos != MemberNotFound)
  {
    vector<Person*>::iterator itr(sessionMembers.begin() + pos);
    delete *itr;
    sessionMembers.erase(itr);
    //call reset to update the sessionView;
    this->reset();
    return true;
  }

  return false;
}

unsigned int Session::FindMember(const Person& person) const
{
  for(unsigned int i=0; i<sessionMembers.size(); i++)
  {
    if(strcmp(person.GetUsername(), sessionMembers[i]->GetUsername()) == 0)
    {
      return i;
    }
  }

  return MemberNotFound;
}

Person* Session::FindMember(const char* username) const
{
  for(unsigned int i=0; i<sessionMembers.size(); i++)
  {
    if(strcmp(username, sessionMembers[i]->GetUsername()) == 0)
    {
      return sessionMembers[i];
    }
  }

  return NULL;
}

Person* Session::FindMember(const SystemAddress& address) const
{
  for(unsigned int i=0; i<sessionMembers.size(); i++)
  {
    if(address == sessionMembers[i]->GetAddress())
    {
      return sessionMembers[i];
    }
  }

  return NULL;
}

Person* Session::FindMember(const short id) const
{
  for(unsigned int i=0; i<sessionMembers.size(); i++)
  {
    if(id == sessionMembers[i]->GetID())
    {
      return sessionMembers[i];
    }
  }

  return NULL;
}

const Person* Session::Deserialize( RakNet::BitStream& bs ) const
{
  SystemAddress address;
  bs.ReadCompressed( address.binaryAddress );
  bs.ReadCompressed( address.port );
  return FindMember( address );
}
