/*
* person.h
*
* Copyright (C) 2008 Mike Gist, Jan Hosang, Daniel Burrell, Dave Lawrence, Andrew Slater
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation (version 2 of the License)
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/

#ifndef __SESSION_H__
#define __SESSION_H__

//====================================================================================
// QT Includes
//====================================================================================
#include <QtCore/QAbstractListModel>

//====================================================================================
// Project Includes
//====================================================================================
#include <vector>
#include "isession.h"
#include "person.h"
#include "raknet/RakNetTypes.h"

//====================================================================================
// Local Includes
//====================================================================================

//------------------------------------------------------------------------------------
// Forward Declarations and Preprocessor Definitions
//------------------------------------------------------------------------------------

class Session : public iSession, public QAbstractListModel
{
public:
  virtual ~Session() { }

  //note DO NOT CHANGE THE CASE SETTING OF rowCount() or data(). Override methods.
  int rowCount ( const QModelIndex & parent = QModelIndex() ) const;
  QVariant data(const QModelIndex & index, int role) const;

  void AddMember(Person* person);
  bool RemoveMember(const Person& person);
  unsigned int FindMember(const Person& person) const;
  Person* FindMember(const char* username) const;
  Person* FindMember(const SystemAddress& address) const;
  Person* FindMember(const short id) const;

  const Person* Deserialize( RakNet::BitStream& bs ) const;

  std::vector<Person*>::const_iterator GetMembers() const { return sessionMembers.begin(); }
  size_t GetMemberCount() const { return sessionMembers.size(); }

private:
  std::vector<Person*> sessionMembers;

  enum
  {
    MemberNotFound = (unsigned int)-1
  };
};

#endif // __SESSION_H__
